"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_1 = require("react");
// eslint-disable-next-line no-unused-vars
const TinyMCE_1 = require("./editors/TinyMCE");
const PlainEditor_1 = require("./editors/PlainEditor");
const react_redux_1 = require("react-redux");
const AsyncActionQueue_1 = require("../lib/AsyncActionQueue");
const MultiNoteActions_1 = require("./MultiNoteActions");
const { themeStyle, buildStyle } = require('../theme.js');
const { reg } = require('lib/registry.js');
const { time } = require('lib/time-utils.js');
const markupLanguageUtils = require('lib/markupLanguageUtils');
const HtmlToHtml = require('lib/joplin-renderer/HtmlToHtml');
const Setting = require('lib/models/Setting');
const BaseItem = require('lib/models/BaseItem');
const { MarkupToHtml } = require('lib/joplin-renderer');
const HtmlToMd = require('lib/HtmlToMd');
const { _ } = require('lib/locale');
const Note = require('lib/models/Note.js');
const BaseModel = require('lib/BaseModel.js');
const Resource = require('lib/models/Resource.js');
const { shim } = require('lib/shim');
const TemplateUtils = require('lib/TemplateUtils');
const { bridge } = require('electron').remote.require('./bridge');
const { urlDecode } = require('lib/string-utils');
const urlUtils = require('lib/urlUtils');
const ResourceFetcher = require('lib/services/ResourceFetcher.js');
const DecryptionWorker = require('lib/services/DecryptionWorker.js');
const defaultNote = () => {
    return {
        id: '',
        parent_id: '',
        title: '',
        is_todo: 0,
        markup_language: 1,
        bodyWillChangeId: 0,
        bodyChangeId: 0,
        saveActionQueue: null,
        originalCss: '',
        hasChanged: false,
    };
};
function styles_(props) {
    return buildStyle('NoteText', props.theme, (theme) => {
        return {
            titleInput: {
                flex: 1,
                display: 'inline-block',
                paddingTop: 5,
                paddingBottom: 5,
                paddingLeft: 8,
                paddingRight: 8,
                marginRight: theme.paddingLeft,
                color: theme.textStyle.color,
                fontSize: theme.textStyle.fontSize * 1.25 * 1.5,
                backgroundColor: theme.backgroundColor,
                border: '1px solid',
                borderColor: theme.dividerColor,
            },
            warningBanner: {
                background: theme.warningBackgroundColor,
                fontFamily: theme.fontFamily,
                padding: 10,
                fontSize: theme.fontSize,
            },
            tinyMCE: {
                width: '100%',
                height: '100%',
            },
        };
    });
}
let textEditorUtils_ = null;
function usePrevious(value) {
    const ref = react_1.useRef();
    react_1.useEffect(() => {
        ref.current = value;
    });
    return ref.current;
}
function initNoteState(n, setFormNote, setDefaultEditorState) {
    return __awaiter(this, void 0, void 0, function* () {
        let originalCss = '';
        if (n.markup_language === MarkupToHtml.MARKUP_LANGUAGE_HTML) {
            const htmlToHtml = new HtmlToHtml();
            const splitted = htmlToHtml.splitHtml(n.body);
            originalCss = splitted.css;
        }
        setFormNote({
            id: n.id,
            title: n.title,
            is_todo: n.is_todo,
            parent_id: n.parent_id,
            bodyWillChangeId: 0,
            bodyChangeId: 0,
            markup_language: n.markup_language,
            saveActionQueue: new AsyncActionQueue_1.default(1000),
            originalCss: originalCss,
            hasChanged: false,
        });
        setDefaultEditorState({
            value: n.body,
            markupLanguage: n.markup_language,
            resourceInfos: yield attachedResources(n.body),
        });
        yield handleResourceDownloadMode(n.body);
    });
}
function handleResourceDownloadMode(noteBody) {
    return __awaiter(this, void 0, void 0, function* () {
        if (noteBody && Setting.value('sync.resourceDownloadMode') === 'auto') {
            const resourceIds = yield Note.linkedResourceIds(noteBody);
            yield ResourceFetcher.instance().markForDownload(resourceIds);
        }
    });
}
function htmlToMarkdown(html) {
    return __awaiter(this, void 0, void 0, function* () {
        const htmlToMd = new HtmlToMd();
        let md = htmlToMd.parse(html, { preserveImageTagsWithSize: true });
        md = yield Note.replaceResourceExternalToInternalLinks(md, { useAbsolutePaths: true });
        return md;
    });
}
function formNoteToNote(formNote) {
    return __awaiter(this, void 0, void 0, function* () {
        const newNote = Object.assign({}, formNote);
        if ('bodyEditorContent' in formNote) {
            const html = yield textEditorUtils_.editorContentToHtml(formNote.bodyEditorContent);
            if (formNote.markup_language === MarkupToHtml.MARKUP_LANGUAGE_MARKDOWN) {
                newNote.body = yield htmlToMarkdown(html);
            }
            else {
                newNote.body = html;
                newNote.body = yield Note.replaceResourceExternalToInternalLinks(newNote.body, { useAbsolutePaths: true });
                if (formNote.originalCss)
                    newNote.body = `<style>${formNote.originalCss}</style>\n${newNote.body}`;
            }
        }
        delete newNote.bodyEditorContent;
        return newNote;
    });
}
let resourceCache_ = {};
function clearResourceCache() {
    resourceCache_ = {};
}
function attachedResources(noteBody) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!noteBody)
            return {};
        const resourceIds = yield Note.linkedItemIdsByType(BaseModel.TYPE_RESOURCE, noteBody);
        const output = {};
        for (let i = 0; i < resourceIds.length; i++) {
            const id = resourceIds[i];
            if (resourceCache_[id]) {
                output[id] = resourceCache_[id];
            }
            else {
                const resource = yield Resource.load(id);
                const localState = yield Resource.localState(resource);
                const o = {
                    item: resource,
                    localState: localState,
                };
                // eslint-disable-next-line require-atomic-updates
                resourceCache_[id] = o;
                output[id] = o;
            }
        }
        return output;
    });
}
function installResourceHandling(refreshResourceHandler) {
    ResourceFetcher.instance().on('downloadComplete', refreshResourceHandler);
    ResourceFetcher.instance().on('downloadStarted', refreshResourceHandler);
    DecryptionWorker.instance().on('resourceDecrypted', refreshResourceHandler);
}
function uninstallResourceHandling(refreshResourceHandler) {
    ResourceFetcher.instance().off('downloadComplete', refreshResourceHandler);
    ResourceFetcher.instance().off('downloadStarted', refreshResourceHandler);
    DecryptionWorker.instance().off('resourceDecrypted', refreshResourceHandler);
}
function attachResources() {
    return __awaiter(this, void 0, void 0, function* () {
        const filePaths = bridge().showOpenDialog({
            properties: ['openFile', 'createDirectory', 'multiSelections'],
        });
        if (!filePaths || !filePaths.length)
            return [];
        const output = [];
        for (const filePath of filePaths) {
            try {
                const resource = yield shim.createResourceFromPath(filePath);
                output.push({
                    item: resource,
                    markdownTag: Resource.markdownTag(resource),
                });
            }
            catch (error) {
                bridge().showErrorMessageBox(error.message);
            }
        }
        return output;
    });
}
function scheduleSaveNote(formNote, dispatch) {
    if (!formNote.saveActionQueue)
        throw new Error('saveActionQueue is not set!!'); // Sanity check
    reg.logger().debug('Scheduling...', formNote);
    const makeAction = (formNote) => {
        return function () {
            return __awaiter(this, void 0, void 0, function* () {
                const note = yield formNoteToNote(formNote);
                reg.logger().debug('Saving note...', note);
                yield Note.save(note);
                dispatch({
                    type: 'EDITOR_NOTE_STATUS_REMOVE',
                    id: formNote.id,
                });
            });
        };
    };
    formNote.saveActionQueue.push(makeAction(formNote));
}
function saveNoteIfWillChange(formNote, editorRef, dispatch) {
    if (!formNote.id || !formNote.bodyWillChangeId)
        return;
    scheduleSaveNote(Object.assign(Object.assign({}, formNote), { bodyEditorContent: editorRef.current.content(), bodyWillChangeId: 0, bodyChangeId: 0 }), dispatch);
}
function useWindowCommand(windowCommand, dispatch, formNote, titleInputRef, editorRef) {
    react_1.useEffect(() => {
        const command = windowCommand;
        if (!command || !formNote)
            return;
        const editorCmd = { name: command.name, value: Object.assign({}, command.value) };
        let fn = null;
        if (command.name === 'exportPdf') {
            // TODO
        }
        else if (command.name === 'print') {
            // TODO
        }
        else if (command.name === 'insertDateTime') {
            editorCmd.name = 'insertText',
                editorCmd.value = time.formatMsToLocal(new Date().getTime());
        }
        else if (command.name === 'commandStartExternalEditing') {
            // TODO
        }
        else if (command.name === 'commandStopExternalEditing') {
            // TODO
        }
        else if (command.name === 'showLocalSearch') {
            editorCmd.name = 'search';
        }
        else if (command.name === 'textCode') {
            // TODO
        }
        else if (command.name === 'insertTemplate') {
            editorCmd.name = 'insertText',
                editorCmd.value = TemplateUtils.render(command.value);
        }
        if (command.name === 'focusElement' && command.target === 'noteTitle') {
            fn = () => {
                if (!titleInputRef.current)
                    return;
                titleInputRef.current.focus();
            };
        }
        if (command.name === 'focusElement' && command.target === 'noteBody') {
            editorCmd.name = 'focus';
        }
        if (!editorCmd.name && !fn)
            return;
        dispatch({
            type: 'WINDOW_COMMAND',
            name: null,
        });
        requestAnimationFrame(() => {
            if (fn) {
                fn();
            }
            else {
                if (!editorRef.current.execCommand) {
                    reg.logger().warn('Received command, but editor cannot execute commands', editorCmd);
                }
                else {
                    editorRef.current.execCommand(editorCmd);
                }
            }
        });
    }, [windowCommand, dispatch, formNote]);
}
function NoteText2(props) {
    const [formNote, setFormNote] = react_1.useState(defaultNote());
    const [defaultEditorState, setDefaultEditorState] = react_1.useState({ value: '', markupLanguage: MarkupToHtml.MARKUP_LANGUAGE_MARKDOWN, resourceInfos: {} });
    const prevSyncStarted = usePrevious(props.syncStarted);
    const editorRef = react_1.useRef();
    const titleInputRef = react_1.useRef();
    const formNoteRef = react_1.useRef();
    formNoteRef.current = Object.assign({}, formNote);
    const isMountedRef = react_1.useRef(true);
    useWindowCommand(props.windowCommand, props.dispatch, formNote, titleInputRef, editorRef);
    // If the note has been modified in another editor, wait for it to be saved
    // before loading it in this editor.
    const waitingToSaveNote = props.noteId && formNote.id !== props.noteId && props.editorNoteStatuses[props.noteId] === 'saving';
    const styles = styles_(props);
    const markupToHtml = react_1.useCallback((markupLanguage, md, options = null) => __awaiter(this, void 0, void 0, function* () {
        md = md || '';
        const theme = themeStyle(props.theme);
        md = yield Note.replaceResourceInternalToExternalLinks(md, { useAbsolutePaths: true });
        const markupToHtml = markupLanguageUtils.newMarkupToHtml({
            resourceBaseUrl: `file://${Setting.value('resourceDir')}/`,
        });
        const result = yield markupToHtml.render(markupLanguage, md, theme, Object.assign({}, {
            codeTheme: theme.codeThemeCss,
            // userCss: this.props.customCss ? this.props.customCss : '',
            // resources: await shared.attachedResources(noteBody),
            resources: [],
            postMessageSyntax: 'ipcProxySendToHost',
            splitted: true,
            externalAssetsOnly: true,
        }, options));
        return result;
    }), [props.theme]);
    const allAssets = react_1.useCallback((markupLanguage) => __awaiter(this, void 0, void 0, function* () {
        const theme = themeStyle(props.theme);
        const markupToHtml = markupLanguageUtils.newMarkupToHtml({
            resourceBaseUrl: `file://${Setting.value('resourceDir')}/`,
        });
        return markupToHtml.allAssets(markupLanguage, theme);
    }), [props.theme]);
    const joplinHtml = react_1.useCallback((type) => __awaiter(this, void 0, void 0, function* () {
        if (type === 'checkbox') {
            const result = yield markupToHtml(MarkupToHtml.MARKUP_LANGUAGE_MARKDOWN, '- [ ] xxxxxREMOVExxxxx', {
                bodyOnly: true,
                externalAssetsOnly: true,
            });
            const html = result.html
                .replace(/xxxxxREMOVExxxxx/m, ' ')
                .replace(/<ul.*?>/, '')
                .replace(/<\/ul>/, '');
            return Object.assign(Object.assign({}, result), { html: html });
        }
        throw new Error(`Invalid type:${type}`);
    }), [markupToHtml]);
    const handleProvisionalFlag = react_1.useCallback(() => {
        if (props.isProvisional) {
            props.dispatch({
                type: 'NOTE_PROVISIONAL_FLAG_CLEAR',
                id: formNote.id,
            });
        }
    }, [props.isProvisional, formNote.id]);
    const refreshResource = react_1.useCallback(function (event) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!defaultEditorState.value)
                return;
            const resourceIds = yield Note.linkedResourceIds(defaultEditorState.value);
            if (resourceIds.indexOf(event.id) >= 0) {
                clearResourceCache();
                const e = Object.assign(Object.assign({}, defaultEditorState), { resourceInfos: yield attachedResources(defaultEditorState.value) });
                setDefaultEditorState(e);
            }
        });
    }, [defaultEditorState]);
    react_1.useEffect(() => {
        installResourceHandling(refreshResource);
        return () => {
            uninstallResourceHandling(refreshResource);
        };
    }, [defaultEditorState]);
    react_1.useEffect(() => {
        // This is not exactly a hack but a bit ugly. If the note was changed (willChangeId > 0) but not
        // yet saved, we need to save it now before the component is unmounted. However, we can't put
        // formNote in the dependency array or that effect will run every time the note changes. We only
        // want to run it once on unmount. So because of that we need to use that formNoteRef.
        return () => {
            isMountedRef.current = false;
            saveNoteIfWillChange(formNoteRef.current, editorRef, props.dispatch);
        };
    }, []);
    react_1.useEffect(() => {
        // Check that synchronisation has just finished - and
        // if the note has never been changed, we reload it.
        // If the note has already been changed, it's a conflict
        // that's already been handled by the synchronizer.
        if (!prevSyncStarted)
            return () => { };
        if (props.syncStarted)
            return () => { };
        if (formNote.hasChanged)
            return () => { };
        reg.logger().debug('Sync has finished and note has never been changed - reloading it');
        let cancelled = false;
        const loadNote = () => __awaiter(this, void 0, void 0, function* () {
            const n = yield Note.load(props.noteId);
            if (cancelled)
                return;
            // Normally should not happened because if the note has been deleted via sync
            // it would not have been loaded in the editor (due to note selection changing
            // on delete)
            if (!n) {
                reg.logger().warn('Trying to reload note that has been deleted:', props.noteId);
                return;
            }
            yield initNoteState(n, setFormNote, setDefaultEditorState);
        });
        loadNote();
        return () => {
            cancelled = true;
        };
    }, [prevSyncStarted, props.syncStarted, formNote]);
    react_1.useEffect(() => {
        if (!props.noteId)
            return () => { };
        if (formNote.id === props.noteId)
            return () => { };
        if (waitingToSaveNote)
            return () => { };
        let cancelled = false;
        reg.logger().debug('Loading existing note', props.noteId);
        saveNoteIfWillChange(formNote, editorRef, props.dispatch);
        function handleAutoFocus(noteIsTodo) {
            if (!props.isProvisional)
                return;
            const focusSettingName = noteIsTodo ? 'newTodoFocus' : 'newNoteFocus';
            requestAnimationFrame(() => {
                if (Setting.value(focusSettingName) === 'title') {
                    if (titleInputRef.current)
                        titleInputRef.current.focus();
                }
                else {
                    if (editorRef.current)
                        editorRef.current.execCommand({ name: 'focus' });
                }
            });
        }
        function loadNote() {
            return __awaiter(this, void 0, void 0, function* () {
                const n = yield Note.load(props.noteId);
                if (cancelled)
                    return;
                if (!n)
                    throw new Error(`Cannot find note with ID: ${props.noteId}`);
                reg.logger().debug('Loaded note:', n);
                yield initNoteState(n, setFormNote, setDefaultEditorState);
                handleAutoFocus(!!n.is_todo);
            });
        }
        loadNote();
        return () => {
            cancelled = true;
        };
    }, [props.noteId, props.isProvisional, formNote, waitingToSaveNote]);
    const onFieldChange = react_1.useCallback((field, value, changeId = 0) => {
        if (!isMountedRef.current) {
            // When the component is unmounted, various actions can happen which can
            // trigger onChange events, for example the textarea might be cleared.
            // We need to ignore these events, otherwise the note is going to be saved
            // with an invalid body.
            reg.logger().debug('Skipping change event because the component is unmounted');
            return;
        }
        handleProvisionalFlag();
        const change = field === 'body' ? {
            bodyEditorContent: value,
        } : {
            title: value,
        };
        const newNote = Object.assign(Object.assign(Object.assign({}, formNote), change), { bodyWillChangeId: 0, bodyChangeId: 0, hasChanged: true });
        if (changeId !== null && field === 'body' && formNote.bodyWillChangeId !== changeId) {
            // Note was changed, but another note was loaded before save - skipping
            // The previously loaded note, that was modified, will be saved via saveNoteIfWillChange()
        }
        else {
            setFormNote(newNote);
            scheduleSaveNote(newNote, props.dispatch);
        }
    }, [handleProvisionalFlag, formNote]);
    const onBodyChange = react_1.useCallback((event) => onFieldChange('body', event.content, event.changeId), [onFieldChange]);
    const onTitleChange = react_1.useCallback((event) => onFieldChange('title', event.target.value), [onFieldChange]);
    const onBodyWillChange = react_1.useCallback((event) => {
        handleProvisionalFlag();
        setFormNote(prev => {
            return Object.assign(Object.assign({}, prev), { bodyWillChangeId: event.changeId, hasChanged: true });
        });
        props.dispatch({
            type: 'EDITOR_NOTE_STATUS_SET',
            id: formNote.id,
            status: 'saving',
        });
    }, [formNote, handleProvisionalFlag]);
    const onMessage = react_1.useCallback((event) => __awaiter(this, void 0, void 0, function* () {
        const msg = event.name;
        const args = event.args;
        console.info('onMessage', msg, args);
        if (msg === 'setMarkerCount') {
            // const ls = Object.assign({}, this.state.localSearch);
            // ls.resultCount = arg0;
            // ls.searching = false;
            // this.setState({ localSearch: ls });
        }
        else if (msg.indexOf('markForDownload:') === 0) {
            // const s = msg.split(':');
            // if (s.length < 2) throw new Error(`Invalid message: ${msg}`);
            // ResourceFetcher.instance().markForDownload(s[1]);
        }
        else if (msg === 'percentScroll') {
            // this.ignoreNextEditorScroll_ = true;
            // this.setEditorPercentScroll(arg0);
        }
        else if (msg === 'contextMenu') {
            // const itemType = arg0 && arg0.type;
            // const menu = new Menu();
            // if (itemType === 'image' || itemType === 'resource') {
            // 	const resource = await Resource.load(arg0.resourceId);
            // 	const resourcePath = Resource.fullPath(resource);
            // 	menu.append(
            // 		new MenuItem({
            // 			label: _('Open...'),
            // 			click: async () => {
            // 				const ok = bridge().openExternal(`file://${resourcePath}`);
            // 				if (!ok) bridge().showErrorMessageBox(_('This file could not be opened: %s', resourcePath));
            // 			},
            // 		})
            // 	);
            // 	menu.append(
            // 		new MenuItem({
            // 			label: _('Save as...'),
            // 			click: async () => {
            // 				const filePath = bridge().showSaveDialog({
            // 					defaultPath: resource.filename ? resource.filename : resource.title,
            // 				});
            // 				if (!filePath) return;
            // 				await fs.copy(resourcePath, filePath);
            // 			},
            // 		})
            // 	);
            // 	menu.append(
            // 		new MenuItem({
            // 			label: _('Copy path to clipboard'),
            // 			click: async () => {
            // 				clipboard.writeText(toSystemSlashes(resourcePath));
            // 			},
            // 		})
            // 	);
            // } else if (itemType === 'text') {
            // 	menu.append(
            // 		new MenuItem({
            // 			label: _('Copy'),
            // 			click: async () => {
            // 				clipboard.writeText(arg0.textToCopy);
            // 			},
            // 		})
            // 	);
            // } else if (itemType === 'link') {
            // 	menu.append(
            // 		new MenuItem({
            // 			label: _('Copy Link Address'),
            // 			click: async () => {
            // 				clipboard.writeText(arg0.textToCopy);
            // 			},
            // 		})
            // 	);
            // } else {
            // 	reg.logger().error(`Unhandled item type: ${itemType}`);
            // 	return;
            // }
            // menu.popup(bridge().window());
        }
        else if (msg === 'openInternal') {
            const resourceUrlInfo = urlUtils.parseResourceUrl(args.url);
            const itemId = resourceUrlInfo.itemId;
            const item = yield BaseItem.loadItemById(itemId);
            if (!item)
                throw new Error(`No item with ID ${itemId}`);
            if (item.type_ === BaseModel.TYPE_RESOURCE) {
                const localState = yield Resource.localState(item);
                if (localState.fetch_status !== Resource.FETCH_STATUS_DONE || !!item.encryption_blob_encrypted) {
                    if (localState.fetch_status === Resource.FETCH_STATUS_ERROR) {
                        bridge().showErrorMessageBox(`${_('There was an error downloading this attachment:')}\n\n${localState.fetch_error}`);
                    }
                    else {
                        bridge().showErrorMessageBox(_('This attachment is not downloaded or not decrypted yet'));
                    }
                    return;
                }
                const filePath = Resource.fullPath(item);
                bridge().openItem(filePath);
            }
            else if (item.type_ === BaseModel.TYPE_NOTE) {
                props.dispatch({
                    type: 'FOLDER_AND_NOTE_SELECT',
                    folderId: item.parent_id,
                    noteId: item.id,
                    hash: resourceUrlInfo.hash,
                    historyAction: 'goto',
                });
            }
            else {
                throw new Error(`Unsupported item type: ${item.type_}`);
            }
        }
        else if (msg.indexOf('#') === 0) {
            // This is an internal anchor, which is handled by the WebView so skip this case
        }
        else if (msg === 'openExternal') {
            if (args.url.indexOf('file://') === 0) {
                // When using the file:// protocol, openExternal doesn't work (does nothing) with URL-encoded paths
                bridge().openExternal(urlDecode(args.url));
            }
            else {
                bridge().openExternal(args.url);
            }
        }
        else {
            bridge().showErrorMessageBox(_('Unsupported link or message: %s', msg));
        }
    }), []);
    const introductionPostLinkClick = react_1.useCallback(() => {
        bridge().openExternal('https://www.patreon.com/posts/34246624');
    }, []);
    if (props.selectedNoteIds.length > 1) {
        return React.createElement(MultiNoteActions_1.default, { theme: props.theme, selectedNoteIds: props.selectedNoteIds, notes: props.notes, dispatch: props.dispatch, watchedNoteFiles: props.watchedNoteFiles, style: props.style });
    }
    const editorProps = {
        ref: editorRef,
        style: styles.tinyMCE,
        onChange: onBodyChange,
        onWillChange: onBodyWillChange,
        onMessage: onMessage,
        defaultEditorState: defaultEditorState,
        markupToHtml: markupToHtml,
        allAssets: allAssets,
        attachResources: attachResources,
        disabled: waitingToSaveNote,
        joplinHtml: joplinHtml,
        theme: props.theme,
    };
    let editor = null;
    if (props.editor === 'TinyMCE') {
        editor = React.createElement(TinyMCE_1.default, Object.assign({}, editorProps));
        textEditorUtils_ = TinyMCE_1.utils;
    }
    else if (props.editor === 'PlainEditor') {
        editor = React.createElement(PlainEditor_1.default, Object.assign({}, editorProps));
        textEditorUtils_ = PlainEditor_1.utils;
    }
    else {
        throw new Error(`Invalid editor: ${props.editor}`);
    }
    return (React.createElement("div", { style: props.style },
        React.createElement("div", { style: { display: 'flex', flexDirection: 'column', height: '100%' } },
            React.createElement("div", { style: styles.warningBanner },
                "This is an experimental WYSIWYG editor for evaluation only. Please do not use with important notes as you may lose some data! See the ",
                React.createElement("a", { style: styles.urlColor, onClick: introductionPostLinkClick, href: "#" }, "introduction post"),
                " for more information."),
            React.createElement("div", { style: { display: 'flex' } },
                React.createElement("input", { type: "text", ref: titleInputRef, disabled: waitingToSaveNote, placeholder: props.isProvisional ? _('Creating new %s...', formNote.is_todo ? _('to-do') : _('note')) : '', style: styles.titleInput, onChange: onTitleChange, value: formNote.title })),
            React.createElement("div", { style: { display: 'flex', flex: 1 } }, editor))));
}
exports.NoteText2Component = NoteText2;
const mapStateToProps = (state) => {
    const noteId = state.selectedNoteIds.length === 1 ? state.selectedNoteIds[0] : null;
    return {
        noteId: noteId,
        notes: state.notes,
        selectedNoteIds: state.selectedNoteIds,
        isProvisional: state.provisionalNoteIds.includes(noteId),
        editorNoteStatuses: state.editorNoteStatuses,
        syncStarted: state.syncStarted,
        theme: state.settings.theme,
        watchedNoteFiles: state.watchedNoteFiles,
        windowCommand: state.windowCommand,
    };
};
exports.default = react_redux_1.connect(mapStateToProps)(NoteText2);
//# sourceMappingURL=NoteText2.js.map